function example1_date
% obtain the minimum of maximum of multiple Rayleigh quotients
% 
    tab = zeros(120,1);
    minf = zeros(120,1);
    error = 0;
    seed = [3 5 7 9 18 24 25 26 27 30];
    n =[6 11 21]; 
    N =[20 100 200 500];
    for i=1 : length(n)
        for j=1 : length(N)
            for k = 1 : length(seed)
                r = seed(k);
                [X, Y, F, timecost, tt, nftime, quadtime] = test_MaxRQ(r, minf(40 * (i-1) + 10 * (j-1) + k), n(i), N(j), error);
                tab(40 * (i-1) + 10 * (j-1) + k,1) = F(end).f;
            end
        end
    end
    fout = fopen('tex_example1_tab.txt','w');
    for i = 1 : 120
        fprintf(fout,'%f\n',tab(i,1));
    end
    fclose(fout);
end



function  [X, Y, F, timecost,tt,nftime,quadtime] = test_MaxRQ(r, minf, n, N, error)
% test of maximum of multiple Rayleigh quotients
%
    fprintf('test for Rayleigh Quotient minimization. \n');
    rand('state', r);
    randn('state', r); 
    method = 1;
    Retraction = 4;
    VT = 19;    
    epsi = 1e-1;
    for i = 1 : N
         Temp = randn(n, n);
         A{i} = diag([1 : n]) + epsi * (Temp' + Temp);
    end 
    
    x1U = randn(n, 1);
    x1.U = orth(x1U);
    H0 = eye(n - 1);

    params.x0 = x1;
    params.H0 = H0;
    params.err = 1e-5;
    params.error = error;
    params.max_t = 5000;
    params.manifold = 2;
    params.rho = 0.1;
    params.mu0 = 0.18;
    params.minstepsize = eps;
    params.maxstepsize = 1;
    params.minf = minf;
    params.thetaA = 0.1;
    params.thetaL = 0.1;
    params.thetaR = 0.45;
    params.thetaT = 0.2;
    params.D = 100;
    params.E = 1; 
    params.gamma = 0.15;
    params.kappa = 0.25;
    params.Gamma = 50;
    params.omega = 2;
    params.update = 1;
    params.t = n - 1;
    
    params.retraction = Retraction;
    params.vector_transport = VT;
    fns = {};

    
    times = 0;
    total_timecost = 0;
    while(total_timecost < 60 && times < 1)
        fprintf('%d: ', times);
        [X, Y, F, timecost,tt,nftime,quadtime] = driver_MaxRQ(A, method, fns, params);
        total_timecost = total_timecost + timecost;
        times = times + 1;
    end
    fprintf('average time cost of %d times is %f. \n', times, total_timecost / times);
end