function example2_2_date
% Tests the sparse vector problem for all algorithms
%
    tab = zeros(60,10);
    minf = ones(60,1);
    error = 0.0001; 
    seed =[1 2 3 5 10 12 13 14 18 20];
    n =[4 6 11 21 51 101];
    m =10 * n;
   
    for i = 1:length(n)
        for j = 1 : length(seed)
            r = seed(j);
            rand('state', r);
            randn('state', r);
            x1.U = orth(rand(n(i), 1)); 
            Q = orth(rand(m(i), n(i)));
            Q(:, 1) = zeros(m(i), 1);
            Q(1, 1) = 1;
            for k = 1 : 5
                method = k;   
                [X, Y, F, timecost, tt, nftime, quadtime]  = test_SV(Q, method, x1, r, minf(10 * (i - 1) + j), n(i), m(i), error);
                tab(10 * (i-1) + j, 2 * (k - 1)+1) = tt;
                tab(10 * (i-1) + j, 2 * k) = timecost;
                disp(r);
            end      
        end
    end

    fout = fopen('tex_example2_2_tab.txt','w');
    for i=1 : 60
        for j = 1 : 10
            fprintf(fout,'%f ',tab(i,j));
        end
        fprintf(fout,'\n');
    end
    fclose(fout);
end


function [X, Y, F, timecost, tt, nftime, quadtime] = test_SV(Q, method, x1, r, minf, n, m, error)
% test of the sparse vector problem
%   
    H0 = eye(n - 1); 
    params.x0 = x1;
    params.H0 = H0;
    
    params.manifold = 2;
    params.error = 1e-4;
    params.minf = minf;
    params.err = 1e-5;
    params.tol = 1e-8;
    params.rho = 0.1;
    params.mu0 = 0.18;
    params.minstepsize = eps;
    params.maxstepsize = 1;
    params.thetaA = 0.1;
    params.thetaL = 0.1;
    params.thetaR = 0.45;
    params.thetaT = 0.2;
    params.m = 8;
    params.D = 1e-6;
    params.E = 1; 

    params.kappa = 0.25;   
    params.omega = 2;
    params.update = 1;
    params.alpha = 1.2;
    params.m_L = 0.0002;
    params.mu_l = 26;
    params.max_L = 50;
    
    params.theta_epsilon = 0.1;
    params.theta_delta = 1; 
    params.c = 0.005;
    params.max_ls = 5000;
    params.delta = 1e-5;
       
    if (method == 1)
        params.t = n - 1; 
        params.Gamma = 50;
        Retraction = 4;
        VT = 19;
        params.gamma = 0.15;       
        params.max_t = inf; 
    elseif (method == 2)
        params.epsilon = 0.05;
        Retraction = 2;
        VT = 7;
        params.max = inf;
        params.max_t = 5000;
    elseif (method == 3)       
        params.epsilon = 0.05;
        Retraction = 4;
        VT = 7;   
        params.max = inf;
        params.max_t = 5000;
    elseif (method == 4)
        params.manifold = 1;
        Retraction = 1;
        VT = 1;
        params.epsilon = 0.1;
        params.gamma = 0.5;
        params.max_t = 5000;
        params.manifold = 1;      
    else        
        params.t = 500; 
        params.Gamma = 1000;
        Retraction = 4;
        VT = 19;
        params.gamma = 0.15;   
        params.max_t = inf; 
    end
    
   
    params.retraction = Retraction;
    params.vector_transport = VT;
    fns = {};         
    times = 0;
    total_timecost = 0;
    while(total_timecost < 60 && times < 1)
        fprintf('%d: ', times);
        [X, Y, F, timecost, tt, nftime, quadtime] = driver_SV(Q, method, fns, params);
        total_timecost = total_timecost + timecost;
        times = times + 1;
    end
    fprintf('average time cost of %d times is %f. \n', times, total_timecost);  
end



