function generate_table_OBB()
% Generate the table in the RQNBM paper
% Use bounding box problem to compare RQNBM, RQNBM-NO and M-RQNBM for
% different ml

    tab = zeros(6, 4);
    m = [0 1 4 8 16 32];
    d =[3 4 5 6 8 10];
    seed = [1 3 5 7 8 9 10 11 14 15;4 5 6 7 8 10 11 12 15 17;1 2 3 4 5 8 10 19 20 22;3 4 10 11 14 16 19 25 29 33;...
        2 6 7 8 10 12 17 26 40 41;7 24 83 100 108 137 153 177 186 197];
    n=1000;
    for i = 1 : length(d)
        for j = 1 : size(seed,2)                       
            for k = 1:length(m)          
                [X, Y, F, timecost, tt, nftime, quadtime] = test_OBB1(seed(i,j), n, d(i), m(k),0);
                seed(i,j)
                tab(k,1) = tab(k,1) + F(end).f;
                tab(k,2) = tab(k,2) + tt;
                tab(k,3) = tab(k,3) + quadtime;
                tab(k,4) = tab(k,4) + timecost; 
            end
        end
    end
    for k=1:6
        
        tab(k,1) = tab(k,1) / (length(d) * size(seed,2)) ;
        tab(k,2) = tab(k,2) / (length(d) * size(seed,2)) ;
        tab(k,3) = tab(k,3) / (length(d) * size(seed,2)) ;
        tab(k,4) = tab(k,4) / (length(d) * size(seed,2)) ;
    end
    fout = fopen('tex_OBB_tab.txt','w');
   
    for i = 1 : 6
        for j = 1 : 4
            str = outputfloat(tab(i, j));
                fprintf(fout,['& $' str '$  ']);         
        end
        fprintf(fout,' \\\\\n');
    end       
    fclose(fout);
end

function str = outputfloat(x)
    if(x <= 0)
        str = '';
        return;
    end
    p = log(x)/log(10);
    p = - ceil(-p);
    x = round(x * 10^(-p) * 100);
    x = x / 100;
    strx = sprintf('%3.2f', x);
    if(p ~= 0)
        str = [strx '_{' num2str(p) '}'];
    else
        str = strx;
    end
end
function [X, Y, F, timecost, tt, nftime, quadtime] = test_OBB1(r, n, d, update, minf)
    fprintf('test for bounding box problem. \n');
%     r = rand();   
%     r = floor(r * 10000);  

    rand('state', r);
    randn('state', r);  
    x1.U = orth(randn(d, d));  
    A = 0.75 * rand(d,n);
    N = d * (d - 1) * 0.5;
    H0 = eye(N);
   
    Retraction = 2;
    VT = 13;
    params.m = update;
    params.update =1; 
    method = 5;
    params.Gamma = 1000;
    params.rho = 0.1;
    params.t = 500;
    
    if(update == 1)
        method = 1;
        params.update = update;
        params.Gamma = 50;
        params.rho = 0.1;
        params.t = 2^d * N;
    elseif(update == 0)
        params.update =0; 
    end
    
    

    params.x0 = x1;
    params.H0 = H0;
    params.err = 1e-5;
    params.error = 0;
    params.max_t = inf;
%     params.max_outer = params.max_t;
    params.manifold = 3;   
    params.mu0 =0.18;
    params.minstepsize = eps;
    params.maxstepsize = 1;
%     params.epsilonf = 5 * 1e-5;
    params.minf =minf;
    params.thetaA = 0.1;
    params.thetaL = 0.1;
    params.thetaR = 0.45;
    params.thetaT = 0.2;
    params.D = 100;
    params.E = 1;    
    params.gamma = 0.15;
    params.kappa = 0.25;    
    params.omega = 2;
    
    params.retraction = Retraction;
    params.vector_transport = VT;
    fns = {};

    
    times = 0;
    total_timecost = 0;
    while(total_timecost < 60 && times < 1)
        fprintf('%d: ', times);
        [X, Y, F, timecost,tt,nftime,quadtime] = driver_OBB(A, method, fns, params);
        total_timecost = total_timecost + timecost;
        times = times + 1;
    end
    fprintf('average time cost of %d times is %f. \n', times, total_timecost / times);
end

