function generate_table_rq()
% Generate the table in the RQNBM paper 
% Use maximum of multiple Rayleigh quotients to test the performance of
% large scaled problem
%
    tab = zeros(5, 10);
    seed=[2 3 4 6 8 9 10 11 12 14; 2 4 5 8 10 12 15 17 19 21];
    size(seed, 2)
    n =[5001 10001];
    N = 2;
    method = [1 5 2 3 4];
    for i = 1 : length(n)
        for j = 1 : length(seed)             
            r = seed(i,j);
            rand('state', r);
            randn('state', r);

            for k = 1 : length(method)
                [X, Y, F, timecost, tt, nftime, quadtime] = test_MaxRQ(r, 0.5, n(i), N, 0, method(k));
                tab(k, 1 + 5 * (i - 1)) = tab(k, 1 + 5 * (i - 1)) + F(end).f;
                tab(k, 2 + 5 * (i - 1)) = tab(k, 2 + 5 * (i - 1)) + tt;
                tab(k, 3 + 5 * (i - 1)) = tab(k, 3 + 5 * (i - 1)) + nftime;
                tab(k, 4 + 5 * (i - 1)) = tab(k, 4 + 5 * (i - 1)) + quadtime;
                tab(k, 5 + 5 * (i - 1)) = tab(k, 5 + 5 * (i - 1)) + timecost; 
           end
        end
    end
    for k = 1 : 5
        tab(k,1) = tab(k,1) /  size(seed, 2);
        tab(k,2) = tab(k,2) /  size(seed, 2);
        tab(k,3) = tab(k,3) /  size(seed, 2);
        tab(k,4) = tab(k,4) /  size(seed, 2);
        tab(k,5) = tab(k,5) /  size(seed, 2);
        tab(k,6) = tab(k,6) /  size(seed, 2);
        tab(k,7) = tab(k,7) /  size(seed, 2);
        tab(k,8) = tab(k,8) /  size(seed, 2);
        tab(k,9) = tab(k,9) /  size(seed, 2);
        tab(k,10) = tab(k,10) / size(seed, 2);
    end
    fout = fopen('tex_SV_e1_tab.txt','w');
   
    for i = 1 : 5
        for j = 1 : 10
            str = outputfloat(tab(i, j));
                fprintf(fout,['& $' str '$  ']);         
        end
        fprintf(fout,' \\\\\n');
    end
    fclose(fout);
%     dlmwrite('tex_tab.txt', tab);
end

function str = outputfloat(x)
    if(x <= 0)
        str = '';
        return;
    end
    p = log(x)/log(10);
    p = - ceil(-p);
    x = round(x * 10^(-p) * 100);
    x = x / 100;
    strx = sprintf('%3.2f', x);
    if(p ~= 0)
        str = [strx '_{' num2str(p) '}'];
    else
        str = strx;
    end
end

function [X, Y, F, timecost, tt, nftime, quadtime] = test_MaxRQ(r, minf, n, N, error, meth)
   fprintf('test for multiple Rayleigh quotients. \n');

%     r = rand();   
%     r = floor(r * 10000);  
    rand('state', r);
    randn('state', r);  
    p = 1;
    method = meth;
    H0 = eye(n - 1);
    x1U = randn(n, 1);
    x1.U = orth(x1U);
    
    
    epsi = 0.1;
    for l = 1 : N
         Temp = sprand(n, n, 0.002);
         B(:, :, l) = diag([1 : n]) + epsi * (Temp' + Temp);           
         A{l} = sparse(B(:, :, l));
    end
   
    params.x0 = x1;
    params.H0 = H0;
    
    params.manifold = 2;
    params.error = 1e-4;
    params.minf = minf;
    params.err = 1e-5;
    params.tol = 1e-8;
    params.rho = 0.1;
    params.mu0 =0.18;
    params.minstepsize = eps;
    params.maxstepsize = 1;
    params.thetaA = 0.1;
    params.thetaL = 0.1;
    params.thetaR = 0.45;
    params.thetaT = 0.2;
    params.m = 8;
    params.D = 100;
    params.E = 1; 

    params.kappa = 0.25;   
    params.omega = 2;
    params.update =1;
    params.alpha = 1.2;
    params.m_L = 0.0002;
    params.mu_l = 26;
    params.max_L = (n - 1)/100;
    
    params.theta_epsilon = 0.1;
    params.theta_delta = 1; 
    params.c = 0.005;
    params.max_ls = 5000;
    params.delta = 1e-5;
       
    if (method == 1)
        params.t = n - 1; 
        params.Gamma = 50;
        Retraction = 4;
        VT = 19;
        params.gamma = 0.15;       
        params.max_t = inf; 
    elseif (method == 2)
        params.epsilon = 0.05;
        Retraction = 2;
        VT = 7;
        params.max = inf;
        params.max_t = 5000;
    elseif (method == 3)       
        params.epsilon = 0.05;
        Retraction = 4;
        VT = 7;   
        params.max = inf;
        params.max_t = 5000;
    elseif (method == 4)
        x1.U = x1U / norm(x1U);
        params.x0 = x1;
        params.manifold = 1;
        Retraction = 1;
        VT = 1;
        params.epsilon = 0.1;
        params.gamma = 0.5;
        params.max_t = 5000;
        params.manifold = 1;      
    else        
        params.t = 500; 
        params.Gamma = 1000;
        Retraction = 4;
        VT = 19;
        params.gamma = 0.15;   
        params.max_t = inf; 
    end
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          
    params.retraction = Retraction;
    params.vector_transport = VT;
    fns = {};
 
    times = 0;
    total_timecost = 0;
    while(total_timecost < 60 && times < 1)
        fprintf('%d: ', times);
        [X, Y, F, timecost, tt, nftime, quadtime] = driver_MaxRQ(A, method, fns, params);
        total_timecost = total_timecost + timecost;
        times = times + 1;
    end

    fprintf('average time cost of %d times is %f. \n', times, total_timecost / times);
end




